==> spip_4.2.13+dfsg.orig.tar.xz: plugins-dist/forum/lang/forum_pt_br.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/forum?lang_cible=pt_br
// ** ne pas modifier le fichier **

return [

	// A
	'aucun_message_forum' => 'Nenhuma mensagem de fórum',

	// B
	'bouton_radio_articles_futurs' => 'apenas às próximas matérias (sem ação sobre a base de dados).',
	'bouton_radio_articles_tous' => 'a todas as matérias, sem exceção.',
	'bouton_radio_articles_tous_sauf_forum_desactive' => 'a todas as matérias, exceto aquelas em que o fórum está desativado.',
	'bouton_radio_enregistrement_obligatoire' => 'Cadastro obrigatório (os usuários devem se cadastrar, fornecendo seu e-mail, antes de poderem enviar suas contribuições).',
	'bouton_radio_moderation_priori' => 'Moderação prévia (as contribuições só serão exibidas publicamente após a aprovação dos administradores).',
	'bouton_radio_modere_abonnement' => 'por assinatura',
	'bouton_radio_modere_posteriori' => 'moderação a posteriori',
	'bouton_radio_modere_priori' => 'moderação a priori',
	'bouton_radio_publication_immediate' => 'Publicação imediata das mensagens
 (as contribuições serão exibidas assim que forem enviadas; os administradores poderão excluí-las em seguida).',

	// D
	'documents_interdits_forum' => 'Documentos proibídos no fórum',

	// E
	'erreur_enregistrement_message' => 'A sua mensagem não pode ser gravada em razão de um problema técnico',
	'extensions_autorisees' => 'Extensões permitidas:',
	'extensions_autorisees_toutes' => 'todas',

	// F
	'form_pet_message_commentaire' => 'Uma mensagem ou comentário?',
	'forum' => 'Fórum',
	'forum_acces_refuse' => 'Você não tem mais acesso a estes fóruns.',
	'forum_attention_dix_caracteres' => '<b>Atenção!</b> Sua mensagem precisa ter pelo menos dez caracteres.',
	'forum_attention_message_non_poste' => 'Atenção, você não postou a sua mensagem!',
	'forum_attention_nb_caracteres_mini' => '<b>Atenção!</b> Sua mensagem deve conter pelo menos @min@ caracteres.',
	'forum_attention_trois_caracteres' => '<b>Atenção!</b> Seu título precisa ter pelo menos três caracteres.',
	'forum_attention_trop_caracteres' => '<b>Atenção!</b> sua mensagem é muito longa (@compte@ caracteres): para que ela seja gravada, ela não pode ultrapassar @max@ caracteres.',
	'forum_avez_selectionne' => 'Você selecionou:',
	'forum_cliquer_retour' => 'Clique <a href=\'@retour_forum@\'>aqui</a> para continuar.',
	'forum_envoyer' => 'Enviar',
	'forum_forum' => 'fórum',
	'forum_info_modere' => 'Este fórum é moderado a priori: a sua contribuição só será exibida após ser validada por um administrador do site.',
	'forum_lien_hyper' => 'Link hipertexto',
	'forum_message' => 'Sua mensagem',
	'forum_message_definitif' => 'Mensagem definitiva: enviar para o site',
	'forum_message_trop_long' => 'Sua mensagem é muito longa. O tamanho máimo é de 20.000 caracteres.',
	'forum_ne_repondez_pas' => 'Não responda a esta mensagem e sim no fórum com o endereço a seguir:',
	'forum_page_url' => '(Se a sua mensagem se refere a uma matéria pubicada na Web, ou a uma página fornecendo mais informações, por favor informe abaixo o título da página e o seu endereço.)',
	'forum_permalink' => 'Link permanente para o comentário',
	'forum_poste_par' => 'Mensagem enviada @parauteur@ a propósito da matéria «@titre@».',
	'forum_poste_par_court' => 'Mensagem postada @parauteur@.',
	'forum_poste_par_generique' => 'Mensagem postada @parauteur@ (@objet@ «@titre@»).',
	'forum_qui_etes_vous' => 'Quem é você?',
	'forum_saisie_texte_info' => 'Este formulário aceita os atalhos do SPIP <code>[->url] {{negrito}} {itálico} <quote> <code></code> e o código HTML <code><q> <del> <ins></code>. Para criar parágrafos, basta deixar uma linha em branco.',
	'forum_texte' => 'Texto da sua mensagem',
	'forum_titre' => 'Título',
	'forum_url' => 'Seu website',
	'forum_valider' => 'Validar a seleção',
	'forum_voir_avant' => 'Visualizar',
	'forum_votre_email' => 'Seu endereço de e-mail',
	'forum_votre_nom' => 'Seu nome',
	'forum_vous_enregistrer' => 'Para participar deste fórum, você precisa se cadastrar previamente. Por favor, informe abaixo o identificador pessoal que lhe foi fornecido. Se você não está cadastrado, você precisa',
	'forum_vous_inscrire' => 'cadastrar-se.',

	// I
	'icone_bruler_message' => 'Marcar como spam',
	'icone_bruler_messages' => 'Marcar como spam',
	'icone_legitimer_message' => 'Marcar como lícita',
	'icone_poster_message' => 'Postar uma mensagem',
	'icone_suivi_forum' => 'Acompanhamento do fórum público: @nb_forums@ contribuição(ões)',
	'icone_suivi_forums' => 'Acompanhar / gerenciar os fóruns',
	'icone_supprimer_message' => 'Suprimir esta mensagem',
	'icone_supprimer_messages' => 'Excluir estas mensagens',
	'icone_valider_message' => 'Validar esta mensagem',
	'icone_valider_messages' => 'Validar estas mensagens',
	'icone_valider_repondre_message' => 'Validar e responder a esta mensagem',
	'info_1_message_forum' => '1 mensagem de fórum',
	'info_activer_forum_public' => 'Para ativar os fóruns públicos, por favor, escolha o modo de moderação padrão:',
	'info_appliquer_choix_moderation' => 'Atribuir esta escolha de moderação:',
	'info_config_forums_prive' => 'Na área restrita do site, você pode ativar diversos tipos de fóruns:',
	'info_config_forums_prive_admin' => 'Um fórum reservado aos administradores do site:',
	'info_config_forums_prive_global' => 'Um fórum global, aberto a todos os redatores:',
	'info_config_forums_prive_objets' => 'Um fórum para cada matéria, nota, site referenciado etc.:',
	'info_desactiver_forum_public' => 'Desativar o uso dos fóruns públicos. Os fóruns públicos poderão ser autorizados caso a caso apenas nas matérias; não serão permitidos nas seções, notas etc.',
	'info_envoi_forum' => 'Envio dos fóruns aos autores das matérias',
	'info_fonctionnement_forum' => 'Funcionamento do fórum:',
	'info_forcer_previsualisation_court' => 'Forçar a previsualização',
	'info_forcer_previsualisation_long' => 'Forçar a previsualização antes de enviar a mensagem',
	'info_forums_liees_mot' => 'As mensagens de fórum vinculadas a esta palavra',
	'info_gauche_suivi_forum_2' => 'A página de <i>acompanhamento dos fóruns</i> é uma ferramenta de gestão do seu site (e não um espaço de discussão ou de redação). Ela exibe todas as contrubuições dos fóruns do site, tanto as do site público como as do espaço privado e permite-lhe gerenciar essas contribuições.',
	'info_liens_syndiques_3' => 'fóruns',
	'info_liens_syndiques_4' => 'são',
	'info_liens_syndiques_5' => 'fórum',
	'info_liens_syndiques_6' => 'é',
	'info_liens_syndiques_7' => 'aguardando validação',
	'info_liens_texte' => 'Link(s) contido(s) no texto da mensagem',
	'info_liens_titre' => 'Link(s) contido(s) no título da mensagem',
	'info_mode_fonctionnement_defaut_forum_public' => 'Modo de funcionamento padrão dos fóruns públicos',
	'info_nb_messages_forum' => '@nb@ mensagens de fórum',
	'info_option_email' => 'Sempre que um visitante postar uma nova mensagem no fórum associado a uma matéria, os autores da matéria podem ser avisados dessa mensagem por e-mail. Informe para cada tipo de fórum se esta oção deve ser usada.',
	'info_pas_de_forum' => 'sem fórum',
	'info_question_visiteur_ajout_document_forum' => 'Se você deseja autorizar os visitantes a anexarem documentos (imagens, áudios...) às suas mensagens em fóruns, indique abaixo a lista das extensões de arquivos permitidos para os fóruns (ex.: gif, jpg, png, mp3).',
	'info_question_visiteur_ajout_document_forum_format' => 'Se você deseja permitir todos os tipos de documentos considerados como seguros pelo SPIP, digite * (asterisco). Para não permitir nenhum, deixe em branco.',
	'info_selectionner_message' => 'Selecione as mensagens:',
	'interface_formulaire' => 'Interface de formulário',
	'interface_onglets' => 'Interface com abas',
	'item_activer_forum_administrateur' => 'Ativar o fórum dos administradores',
	'item_config_forums_prive_global' => 'Ativar os fóruns dos redatores',
	'item_config_forums_prive_objets' => 'Ativar estes fóruns',
	'item_desactiver_forum_administrateur' => 'Desativar o fórum dos administradores',
	'item_non_config_forums_prive_global' => 'Desativar o fórum dos redatores',
	'item_non_config_forums_prive_objets' => 'Desativar estes fóruns',

	// L
	'label_selectionner' => 'Selecionar:',
	'lien_reponse_article' => 'Resposta à matéria',
	'lien_reponse_breve_2' => 'Resposta à nota',
	'lien_reponse_message' => 'Resposta à mensagem',
	'lien_reponse_rubrique' => 'Resposta à seção',
	'lien_reponse_site_reference' => 'resposta ao site referenciado',
	'lien_vider_selection' => 'Limpar a seleção',

	// M
	'messages_aucun' => 'Nenhuma',
	'messages_meme_auteur' => 'Todas as mensagens deste autor',
	'messages_meme_email' => 'Todas as mensagens deste e-mail',
	'messages_meme_ip' => 'Todas as mensagens desse IP',
	'messages_off' => 'Apagadas',
	'messages_perso' => 'Pessoais',
	'messages_privadm' => 'Administradores',
	'messages_prive' => 'Particulares',
	'messages_privoff' => 'Apagadas',
	'messages_privrac' => 'Gerais',
	'messages_prop' => 'Propostas',
	'messages_publie' => 'Publicadas',
	'messages_spam' => 'Spam',
	'messages_tous' => 'Todas',

	// O
	'onglet_messages_internes' => 'Mensagens internas',
	'onglet_messages_publics' => 'Mensagens públicas',
	'onglet_messages_vide' => 'Mensagens sem texto',

	// R
	'repondre_message' => 'Responder a esta mensagem',

	// S
	'statut_off' => 'Apagado',
	'statut_original' => 'original',
	'statut_prop' => 'Proposta',
	'statut_publie' => 'Publicada',
	'statut_spam' => 'Spam',

	// T
	'text_article_propose_publication_forum' => 'Não hesite a dar a sua contribuição no fórum associado a esta matéria (no pé da página).',
	'texte_en_cours_validation' => 'Os conteúdos a seguir estão aguardando aprovação.',
	'texte_en_cours_validation_forum' => 'Não hesite a dar a sua opinião sobre as mesmas nos fóruns a elas associados.',
	'texte_messages_publics' => 'Mensagens publicas de:',
	'titre_cadre_forum_administrateur' => 'Fórum privado dos administradores',
	'titre_cadre_forum_interne' => 'Fórum interno',
	'titre_config_forums_prive' => 'Fóruns da área privada',
	'titre_forum' => 'Fórum',
	'titre_forum_suivi' => 'Acompanhamento dos fóruns',
	'titre_page_forum_suivi' => 'Acompanhamento dos fóruns',
	'titre_selection_action' => 'Seleção',
	'tout_voir' => 'Ver tudo',

	// V
	'voir_messages_objet' => 'ver as mensagens',
];

==> spip_4.3.1+dfsg.orig.tar.xz: plugins-dist/forum/lang/forum_pt_br.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/forum?lang_cible=pt_br
// ** ne pas modifier le fichier **

return [

	// A
	'aucun_message_forum' => 'Nenhuma mensagem de fórum',

	// B
	'bouton_radio_articles_futurs' => 'apenas às próximas matérias (sem ação sobre a base de dados).',
	'bouton_radio_articles_tous' => 'a todas as matérias, sem exceção.',
	'bouton_radio_articles_tous_sauf_forum_desactive' => 'a todas as matérias, exceto aquelas em que o fórum está desativado.',
	'bouton_radio_enregistrement_obligatoire' => 'Cadastro obrigatório (os usuários devem se cadastrar, fornecendo seu e-mail, antes de poderem enviar suas contribuições).', # MODIF
	'bouton_radio_moderation_priori' => 'Moderação prévia (as contribuições só serão exibidas publicamente após a aprovação dos administradores).', # MODIF
	'bouton_radio_modere_abonnement' => 'por assinatura',
	'bouton_radio_modere_posteriori' => 'moderação a posteriori',
	'bouton_radio_modere_priori' => 'moderação a priori',
	'bouton_radio_publication_immediate' => 'Publicação imediata das mensagens
 (as contribuições serão exibidas assim que forem enviadas; os administradores poderão excluí-las em seguida).', # MODIF

	// D
	'documents_interdits_forum' => 'Documentos proibídos no fórum',

	// E
	'erreur_enregistrement_message' => 'A sua mensagem não pode ser gravada em razão de um problema técnico',
	'extensions_autorisees' => 'Extensões permitidas:',
	'extensions_autorisees_toutes' => 'todas',

	// F
	'form_pet_message_commentaire' => 'Uma mensagem ou comentário?',
	'forum' => 'Fórum',
	'forum_acces_refuse' => 'Você não tem mais acesso a estes fóruns.',
	'forum_attention_dix_caracteres' => '<b>Atenção!</b> Sua mensagem precisa ter pelo menos dez caracteres.',
	'forum_attention_message_non_poste' => 'Atenção, você não postou a sua mensagem!',
	'forum_attention_nb_caracteres_mini' => '<b>Atenção!</b> Sua mensagem deve conter pelo menos @min@ caracteres.',
	'forum_attention_trois_caracteres' => '<b>Atenção!</b> Seu título precisa ter pelo menos três caracteres.',
	'forum_attention_trop_caracteres' => '<b>Atenção!</b> sua mensagem é muito longa (@compte@ caracteres): para que ela seja gravada, ela não pode ultrapassar @max@ caracteres.',
	'forum_avez_selectionne' => 'Você selecionou:',
	'forum_cliquer_retour' => 'Clique <a href=\'@retour_forum@\'>aqui</a> para continuar.',
	'forum_envoyer' => 'Enviar',
	'forum_forum' => 'fórum',
	'forum_info_modere' => 'Este fórum é moderado a priori: a sua contribuição só será exibida após ser validada por um administrador do site.', # MODIF
	'forum_lien_hyper' => 'Link hipertexto',
	'forum_message' => 'Sua mensagem',
	'forum_message_definitif' => 'Mensagem definitiva: enviar para o site',
	'forum_message_trop_long' => 'Sua mensagem é muito longa. O tamanho máimo é de 20.000 caracteres.',
	'forum_ne_repondez_pas' => 'Não responda a esta mensagem e sim no fórum com o endereço a seguir:',
	'forum_page_url' => '(Se a sua mensagem se refere a uma matéria pubicada na Web, ou a uma página fornecendo mais informações, por favor informe abaixo o título da página e o seu endereço.)',
	'forum_permalink' => 'Link permanente para o comentário',
	'forum_poste_par' => 'Mensagem enviada @parauteur@ a propósito da matéria «@titre@».',
	'forum_poste_par_court' => 'Mensagem postada @parauteur@.',
	'forum_poste_par_generique' => 'Mensagem postada @parauteur@ (@objet@ «@titre@»).',
	'forum_qui_etes_vous' => 'Quem é você?',
	'forum_saisie_texte_info' => 'Este formulário aceita os atalhos do SPIP <code>[->url] {{negrito}} {itálico} <quote> <code></code> e o código HTML <code><q> <del> <ins></code>. Para criar parágrafos, basta deixar uma linha em branco.',
	'forum_texte' => 'Texto da sua mensagem',
	'forum_titre' => 'Título',
	'forum_url' => 'Seu website',
	'forum_valider' => 'Validar a seleção',
	'forum_voir_avant' => 'Visualizar',
	'forum_votre_email' => 'Seu endereço de e-mail',
	'forum_votre_nom' => 'Seu nome',
	'forum_vous_enregistrer' => 'Para participar deste fórum, você precisa se cadastrar previamente. Por favor, informe abaixo o identificador pessoal que lhe foi fornecido. Se você não está cadastrado, você precisa',
	'forum_vous_inscrire' => 'cadastrar-se.',

	// I
	'icone_bruler_message' => 'Marcar como spam',
	'icone_bruler_messages' => 'Marcar como spam',
	'icone_legitimer_message' => 'Marcar como lícita',
	'icone_poster_message' => 'Postar uma mensagem',
	'icone_suivi_forum' => 'Acompanhamento do fórum público: @nb_forums@ contribuição(ões)',
	'icone_suivi_forums' => 'Acompanhar / gerenciar os fóruns',
	'icone_supprimer_message' => 'Suprimir esta mensagem',
	'icone_supprimer_messages' => 'Excluir estas mensagens',
	'icone_valider_message' => 'Validar esta mensagem',
	'icone_valider_messages' => 'Validar estas mensagens',
	'icone_valider_repondre_message' => 'Validar e responder a esta mensagem',
	'info_1_message_forum' => '1 mensagem de fórum',
	'info_activer_forum_public' => 'Para ativar os fóruns públicos, por favor, escolha o modo de moderação padrão:',
	'info_appliquer_choix_moderation' => 'Atribuir esta escolha de moderação:',
	'info_config_forums_prive' => 'Na área restrita do site, você pode ativar diversos tipos de fóruns:',
	'info_config_forums_prive_admin' => 'Um fórum reservado aos administradores do site:', # MODIF
	'info_config_forums_prive_global' => 'Um fórum global, aberto a todos os redatores:', # MODIF
	'info_config_forums_prive_objets' => 'Um fórum para cada matéria, nota, site referenciado etc.:',
	'info_desactiver_forum_public' => 'Desativar o uso dos fóruns públicos. Os fóruns públicos poderão ser autorizados caso a caso apenas nas matérias; não serão permitidos nas seções, notas etc.',
	'info_envoi_forum' => 'Envio dos fóruns aos autores das matérias', # MODIF
	'info_fonctionnement_forum' => 'Funcionamento do fórum:',
	'info_forcer_previsualisation_court' => 'Forçar a previsualização',
	'info_forcer_previsualisation_long' => 'Forçar a previsualização antes de enviar a mensagem',
	'info_forums_liees_mot' => 'As mensagens de fórum vinculadas a esta palavra',
	'info_gauche_suivi_forum_2' => 'A página de <i>acompanhamento dos fóruns</i> é uma ferramenta de gestão do seu site (e não um espaço de discussão ou de redação). Ela exibe todas as contrubuições dos fóruns do site, tanto as do site público como as do espaço privado e permite-lhe gerenciar essas contribuições.',
	'info_liens_syndiques_3' => 'fóruns',
	'info_liens_syndiques_4' => 'são',
	'info_liens_syndiques_5' => 'fórum',
	'info_liens_syndiques_6' => 'é',
	'info_liens_syndiques_7' => 'aguardando validação',
	'info_liens_texte' => 'Link(s) contido(s) no texto da mensagem',
	'info_liens_titre' => 'Link(s) contido(s) no título da mensagem',
	'info_mode_fonctionnement_defaut_forum_public' => 'Modo de funcionamento padrão dos fóruns públicos',
	'info_nb_messages_forum' => '@nb@ mensagens de fórum',
	'info_option_email' => 'Sempre que um visitante postar uma nova mensagem no fórum associado a uma matéria, os autores da matéria podem ser avisados dessa mensagem por e-mail. Informe para cada tipo de fórum se esta oção deve ser usada.', # MODIF
	'info_pas_de_forum' => 'sem fórum',
	'info_question_visiteur_ajout_document_forum' => 'Se você deseja autorizar os visitantes a anexarem documentos (imagens, áudios...) às suas mensagens em fóruns, indique abaixo a lista das extensões de arquivos permitidos para os fóruns (ex.: gif, jpg, png, mp3).', # MODIF
	'info_question_visiteur_ajout_document_forum_format' => 'Se você deseja permitir todos os tipos de documentos considerados como seguros pelo SPIP, digite * (asterisco). Para não permitir nenhum, deixe em branco.',
	'info_selectionner_message' => 'Selecione as mensagens:',
	'interface_formulaire' => 'Interface de formulário',
	'interface_onglets' => 'Interface com abas',
	'item_activer_forum_administrateur' => 'Ativar o fórum dos administradores', # MODIF
	'item_config_forums_prive_global' => 'Ativar os fóruns dos redatores', # MODIF
	'item_config_forums_prive_objets' => 'Ativar estes fóruns',
	'item_desactiver_forum_administrateur' => 'Desativar o fórum dos administradores', # MODIF
	'item_non_config_forums_prive_global' => 'Desativar o fórum dos redatores', # MODIF
	'item_non_config_forums_prive_objets' => 'Desativar estes fóruns',

	// L
	'label_selectionner' => 'Selecionar:',
	'lien_reponse_article' => 'Resposta à matéria',
	'lien_reponse_breve_2' => 'Resposta à nota',
	'lien_reponse_message' => 'Resposta à mensagem',
	'lien_reponse_rubrique' => 'Resposta à seção',
	'lien_reponse_site_reference' => 'resposta ao site referenciado',
	'lien_vider_selection' => 'Limpar a seleção',

	// M
	'messages_aucun' => 'Nenhuma',
	'messages_meme_auteur' => 'Todas as mensagens deste autor', # MODIF
	'messages_meme_email' => 'Todas as mensagens deste e-mail',
	'messages_meme_ip' => 'Todas as mensagens desse IP',
	'messages_off' => 'Apagadas',
	'messages_perso' => 'Pessoais',
	'messages_privadm' => 'Administradores', # MODIF
	'messages_prive' => 'Particulares',
	'messages_privoff' => 'Apagadas',
	'messages_privrac' => 'Gerais',
	'messages_prop' => 'Propostas',
	'messages_publie' => 'Publicadas',
	'messages_spam' => 'Spam',
	'messages_tous' => 'Todas',

	// O
	'onglet_messages_internes' => 'Mensagens internas',
	'onglet_messages_publics' => 'Mensagens públicas',
	'onglet_messages_vide' => 'Mensagens sem texto',

	// R
	'repondre_message' => 'Responder a esta mensagem',

	// S
	'statut_off' => 'Apagado',
	'statut_original' => 'original',
	'statut_prop' => 'Proposta',
	'statut_publie' => 'Publicada',
	'statut_spam' => 'Spam',

	// T
	'text_article_propose_publication_forum' => 'Não hesite a dar a sua contribuição no fórum associado a esta matéria (no pé da página).',
	'texte_en_cours_validation' => 'Os conteúdos a seguir estão aguardando aprovação.',
	'texte_en_cours_validation_forum' => 'Não hesite a dar a sua opinião sobre as mesmas nos fóruns a elas associados.',
	'texte_messages_publics' => 'Mensagens publicas de:',
	'titre_cadre_forum_administrateur' => 'Fórum privado dos administradores', # MODIF
	'titre_cadre_forum_interne' => 'Fórum interno',
	'titre_config_forums_prive' => 'Fóruns da área privada',
	'titre_forum' => 'Fórum',
	'titre_forum_suivi' => 'Acompanhamento dos fóruns',
	'titre_page_forum_suivi' => 'Acompanhamento dos fóruns',
	'titre_selection_action' => 'Seleção',
	'tout_voir' => 'Ver tudo',

	// V
	'voir_messages_objet' => 'ver as mensagens',
];
